@@ -1,7 +1,9 @@
 package Log::ger::UseDataDumper;
 
-our $DATE = '2019-05-08'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2020-04-17'; # DATE
+our $DIST = 'Log-ger-UseDataDumper'; # DIST
+our $VERSION = '0.003'; # VERSION
 
 use Data::Dumper ();
 use Log::ger ();
@@ -57,7 +59,7 @@ Log::ger::UseDataDumper - Use Data::Dumper (with nicer defaults) to dump data st
 
 =head1 VERSION
 
-This document describes version 0.002 of Log::ger::UseDataDumper (from Perl distribution Log-ger-UseDataDumper), released on 2019-05-08.
+This document describes version 0.003 of Log::ger::UseDataDumper (from Perl distribution Log-ger-UseDataDumper), released on 2020-04-17.
 
 =head1 SYNOPSIS
 
@@ -103,7 +105,8 @@ L<Log::ger>
 
 L<Data::Dumper>
 
-L<Log::ger::UseDataDump>, L<Log::ger::UseDataDumpColor>
+Other modules to set data dumper for Log::ger: L<Log::ger::UseDataDump>,
+L<Log::ger::UseDataDumpColor>, L<Log::ger::UseDataPrinter>.
 
 =head1 AUTHOR
 
@@ -111,7 +114,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019, 2018 by perlancar@cpan.org.
+This software is copyright (c) 2020, 2019, 2018 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
